/*$Id: d_dot.h,v 17.4 2000/03/19 04:20:02 al Exp $ -*- C++ -*-
 $ a "dot card"
 */
#ifndef D_DOT_H
#define D_DOT_H
#include "e_card.h"
/*--------------------------------------------------------------------------*/
class DEV_DOT : public CARD {
private:
  std::string	_s;
  explicit DEV_DOT(const DEV_DOT& p) :CARD(p) {untested(); set_constant(true);}
public:
  explicit	DEV_DOT()		:CARD() {set_constant(true);}
private: // override virtual
  char		id_letter()const	{return '\0';}
  const char*	dev_type()const		{untested(); return "dotcard";}
  CARD*		clone()const		{untested();return new DEV_DOT(*this);}
  void		parse(CS&);
  void		print(OMSTREAM&,int)const;
};
/*--------------------------------------------------------------------------*/
/*--------------------------------------------------------------------------*/
#endif
